@@ -18,6 +18,7 @@ import (
 	"github.com/abiosoft/colima/embedded"
 	"github.com/abiosoft/colima/environment"
 	"github.com/abiosoft/colima/environment/container/docker"
+	"github.com/abiosoft/colima/environment/container/incus"
 	"github.com/abiosoft/colima/environment/container/kubernetes"
 	"github.com/abiosoft/colima/util"
 	"github.com/abiosoft/colima/util/osutil"
@@ -145,7 +146,7 @@ func init() {
 	defaultVMType = environment.DefaultVMType()
 
 	mounts := strings.Join([]string{defaultMountTypeQEMU, "9p", "virtiofs"}, ", ")
-	types := strings.Join([]string{defaultVMType, "vz"}, ", ")
+	types := strings.Join([]string{"qemu", "vz"}, ", ")
 
 	saveConfigDefault := true
 	if envSaveConfig.Exists() {
@@ -157,11 +158,12 @@ func init() {
 	startCmd.Flags().BoolVar(&startCmdArgs.Flags.ActivateRuntime, "activate", true, "set as active Docker/Kubernetes context on startup")
 	startCmd.Flags().IntVarP(&startCmdArgs.CPU, "cpu", "c", defaultCPU, "number of CPUs")
 	startCmd.Flags().StringVar(&startCmdArgs.CPUType, "cpu-type", "", "the CPU type, options can be checked with 'qemu-system-"+defaultArch+" -cpu help'")
-	startCmd.Flags().IntVarP(&startCmdArgs.Memory, "memory", "m", defaultMemory, "memory in GiB")
+	startCmd.Flags().Float32VarP(&startCmdArgs.Memory, "memory", "m", defaultMemory, "memory in GiB")
 	startCmd.Flags().IntVarP(&startCmdArgs.Disk, "disk", "d", defaultDisk, "disk size in GiB")
 	startCmd.Flags().StringVarP(&startCmdArgs.Arch, "arch", "a", defaultArch, "architecture (aarch64, x86_64)")
 	startCmd.Flags().BoolVarP(&startCmdArgs.Flags.Foreground, "foreground", "f", false, "Keep colima in the foreground")
 	startCmd.Flags().StringVar(&startCmdArgs.Hostname, "hostname", "", "custom hostname for the virtual machine")
+	startCmd.Flags().StringVarP(&startCmdArgs.DiskImage, "disk-image", "i", "", "file path to a custom disk image")
 
 	// host IP addresses
 	startCmd.Flags().BoolVar(&startCmdArgs.Network.HostAddresses, "network-host-addresses", false, "support port forwarding to specific host IP addresses")
@@ -286,6 +288,15 @@ func setFlagDefaults(cmd *cobra.Command) {
 			}
 		}
 	}
+
+	// always enable nested virtualization for incus, if supported and not explicitly disabled.
+	if util.MacOSNestedVirtualizationSupported() {
+		if !cmd.Flag("nested-virtualization").Changed {
+			if startCmdArgs.Runtime == incus.Name && startCmdArgs.VMType == "vz" {
+				startCmdArgs.NestedVirtualization = true
+			}
+		}
+	}
 }
 
 func setConfigDefaults(conf *config.Config) {
