@@ -7,6 +7,7 @@ import (
 
 var statusCmdArgs struct {
 	extended bool
+	json     bool
 }
 
 // statusCmd represents the status command
@@ -16,7 +17,7 @@ var statusCmd = &cobra.Command{
 	Long:  `Show the status of Colima`,
 	Args:  cobra.MaximumNArgs(1),
 	RunE: func(cmd *cobra.Command, args []string) error {
-		return newApp().Status(statusCmdArgs.extended)
+		return newApp().Status(statusCmdArgs.extended, statusCmdArgs.json)
 	},
 }
 
@@ -24,4 +25,5 @@ func init() {
 	root.Cmd().AddCommand(statusCmd)
 
 	statusCmd.Flags().BoolVarP(&statusCmdArgs.extended, "extended", "e", false, "include additional details")
+	statusCmd.Flags().BoolVarP(&statusCmdArgs.json, "json", "j", false, "print json output")
 }
