@@ -28,7 +28,7 @@ var (
 type Config struct {
 	CPU      int               `yaml:"cpu,omitempty"`
 	Disk     int               `yaml:"disk,omitempty"`
-	Memory   int               `yaml:"memory,omitempty"`
+	Memory   float32           `yaml:"memory,omitempty"`
 	Arch     string            `yaml:"arch,omitempty"`
 	CPUType  string            `yaml:"cpuType,omitempty"`
 	Network  Network           `yaml:"network,omitempty"`
@@ -44,6 +44,7 @@ type Config struct {
 	VMType               string `yaml:"vmType,omitempty"`
 	VZRosetta            bool   `yaml:"rosetta,omitempty"`
 	NestedVirtualization bool   `yaml:"nestedVirtualization,omitempty"`
+	DiskImage            string `yaml:"diskImage,omitempty"`
 
 	// volume mounts
 	Mounts       []Mount `yaml:"mounts,omitempty"`
