@@ -3,6 +3,7 @@ package containerd
 import (
 	"context"
 	_ "embed"
+	"fmt"
 	"path/filepath"
 	"time"
 
@@ -101,3 +102,7 @@ func (c containerdRuntime) Version(ctx context.Context) string {
 	version, _ := c.guest.RunOutput("sudo", "nerdctl", "version", "--format", `client: {{.Client.Version}}{{printf "\n"}}server: {{(index .Server.Components 0).Version}}`)
 	return version
 }
+
+func (c *containerdRuntime) Update(ctx context.Context) (bool, error) {
+	return false, fmt.Errorf("update not supported for the %s runtime", Name)
+}
