@@ -18,7 +18,7 @@ import (
 
 const (
 	Name           = "kubernetes"
-	DefaultVersion = "v1.30.2+k3s1"
+	DefaultVersion = "v1.31.2+k3s1"
 
 	ConfigKey = "kubernetes_config"
 )
@@ -263,3 +263,7 @@ func (c kubernetesRuntime) Version(context.Context) string {
 	version, _ := c.host.RunOutput("kubectl", "--context", config.CurrentProfile().ID, "version", "--short")
 	return version
 }
+
+func (c *kubernetesRuntime) Update(ctx context.Context) (bool, error) {
+	return false, fmt.Errorf("update not supported for the %s runtime", Name)
+}
