@@ -60,7 +60,7 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 		l.CPUs = &conf.CPU
 	}
 	if conf.Memory > 0 {
-		l.Memory = fmt.Sprintf("%dGiB", conf.Memory)
+		l.Memory = fmt.Sprintf("%dMiB", uint32(conf.Memory*1024))
 	}
 	if conf.Disk > 0 {
 		l.Disk = fmt.Sprintf("%dGiB", conf.Disk)
@@ -135,6 +135,7 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 				l.Networks = append(l.Networks, limaconfig.Network{
 					VZNAT:     true,
 					Interface: limautil.NetInterface,
+					Metric:    limautil.NetMetric,
 				})
 			} else {
 				reachableIPAddress, _ = ctx.Value(daemon.CtxKey(vmnet.Name)).(bool)
@@ -151,6 +152,7 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 						l.Networks = append(l.Networks, limaconfig.Network{
 							Socket:    socketFile,
 							Interface: limautil.NetInterface,
+							Metric:    limautil.NetMetric,
 						})
 
 						return nil
